package com.bpcl.lpg.core.service.impl;

import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Required;
import java.io.InputStream;
import de.hybris.platform.servicelayer.exceptions.SystemException;
import de.hybris.platform.servicelayer.search.FlexibleSearchQuery;
import java.util.Optional;
import de.hybris.platform.catalog.model.CatalogUnawareMediaModel;
import de.hybris.platform.core.model.media.MediaModel;
import de.hybris.platform.servicelayer.search.FlexibleSearchService;
import de.hybris.platform.servicelayer.model.ModelService;
import de.hybris.platform.servicelayer.media.MediaService;
import org.slf4j.Logger;
import com.bpcl.lpg.core.service.BpcllpgcoreService;

public class DefaultBpcllpgcoreService implements BpcllpgcoreService
{
    private static final Logger LOG;
    private MediaService mediaService;
    private ModelService modelService;
    private FlexibleSearchService flexibleSearchService;
    private static final String FIND_LOGO_QUERY = "SELECT {pk} FROM {CatalogUnawareMedia} WHERE {code}=?code";
    
    public String getHybrisLogoUrl(final String logoCode) {
        final MediaModel media = this.mediaService.getMedia(logoCode);
        DefaultBpcllpgcoreService.LOG.debug("Found media [code: {}]", media.getCode());
        return media.getURL();
    }
    
    public void createLogo(final String logoCode) {
        final Optional<CatalogUnawareMediaModel> existingLogo = this.findExistingLogo(logoCode);
        final CatalogUnawareMediaModel media = (CatalogUnawareMediaModel)(existingLogo.isPresent() ? existingLogo.get() : this.modelService.create((Class)CatalogUnawareMediaModel.class));
        media.setCode(logoCode);
        media.setRealFileName("sap-hybris-platform.png");
        this.modelService.save((Object)media);
        this.mediaService.setStreamForMedia((MediaModel)media, this.getImageStream());
    }
    
    private Optional<CatalogUnawareMediaModel> findExistingLogo(final String logoCode) {
        final FlexibleSearchQuery fQuery = new FlexibleSearchQuery("SELECT {pk} FROM {CatalogUnawareMedia} WHERE {code}=?code");
        fQuery.addQueryParameter("code", (Object)logoCode);
        try {
            return Optional.of(this.flexibleSearchService.searchUnique(fQuery));
        }
        catch (final SystemException e) {
            return Optional.empty();
        }
    }
    
    private InputStream getImageStream() {
        return DefaultBpcllpgcoreService.class.getResourceAsStream("/bpcllpgcore/sap-hybris-platform.png");
    }
    
    @Required
    public void setMediaService(final MediaService mediaService) {
        this.mediaService = mediaService;
    }
    
    @Required
    public void setModelService(final ModelService modelService) {
        this.modelService = modelService;
    }
    
    @Required
    public void setFlexibleSearchService(final FlexibleSearchService flexibleSearchService) {
        this.flexibleSearchService = flexibleSearchService;
    }
    
    static {
        LOG = LoggerFactory.getLogger(DefaultBpcllpgcoreService.class);
    }
}
